==> jodd-http-4.1.0-sources.jar: jodd/http/up/ByteArrayUploadable.java <==
// Copyright (c) 2003-present, Jodd Team (http://jodd.org)
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

package jodd.http.up;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;

/**
 * Uploadable wrapper of <code>byte array</code>.
 */
public class ByteArrayUploadable implements Uploadable<byte[]> {

	protected final byte[] byteArray;
	protected final String fileName;
	protected final String mimeType;

	public ByteArrayUploadable(final byte[] byteArray, final String fileName) {
		this.byteArray = byteArray;
		this.fileName = fileName;
		this.mimeType = null;
	}

	public ByteArrayUploadable(final byte[] byteArray, final String fileName, final String mimeType) {
		this.byteArray = byteArray;
		this.fileName = fileName;
		this.mimeType = mimeType;
	}

	public byte[] getContent() {
		return byteArray;
	}

	public byte[] getBytes() {
		return byteArray;
	}

	public String getFileName() {
		return fileName;
	}

	public String getMimeType() {
		return mimeType;
	}

	public int getSize() {
		return byteArray.length;
	}

	public InputStream openInputStream() throws IOException {
		return new ByteArrayInputStream(byteArray);
	}
}

==> jodd-http-5.1.0-sources.jar: jodd/http/up/ByteArrayUploadable.java <==
// Copyright (c) 2003-present, Jodd Team (http://jodd.org)
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

package jodd.http.up;

import java.io.ByteArrayInputStream;
import java.io.InputStream;

/**
 * Uploadable wrapper of <code>byte array</code>.
 */
public class ByteArrayUploadable implements Uploadable<byte[]> {

	protected final byte[] byteArray;
	protected final String fileName;
	protected final String mimeType;

	public ByteArrayUploadable(final byte[] byteArray, final String fileName) {
		this.byteArray = byteArray;
		this.fileName = fileName;
		this.mimeType = null;
	}

	public ByteArrayUploadable(final byte[] byteArray, final String fileName, final String mimeType) {
		this.byteArray = byteArray;
		this.fileName = fileName;
		this.mimeType = mimeType;
	}

	@Override
	public byte[] getContent() {
		return byteArray;
	}

	@Override
	public byte[] getBytes() {
		return byteArray;
	}

	@Override
	public String getFileName() {
		return fileName;
	}

	@Override
	public String getMimeType() {
		return mimeType;
	}

	@Override
	public int getSize() {
		return byteArray.length;
	}

	@Override
	public InputStream openInputStream() {
		return new ByteArrayInputStream(byteArray);
	}
}
